@@ -1,5 +1,5 @@
 /*
- *  $Id: defFind.c,v 1.16 2001/04/15 20:13:53 bkorb Exp $
+ *  $Id: defFind.c,v 1.17 2001/04/30 03:38:32 bkorb Exp $
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition (except the fixed "rootEntry" entry).
@@ -372,7 +372,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
  *  to traverse the list of twins).
  */
     STATIC tDefEntry*
-defEntrySearch( char* pzName, tDefEntry* pDefs, ag_bool* pIsIndexed )
+defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
 {
     char*        pcBrace;
     char         breakCh;
@@ -396,10 +396,10 @@ defEntrySearch( char* pzName, tDefEntry* pDefs, ag_bool* pIsIndexed )
              *pIsIndexed = AG_FALSE;
         else pIsIndexed  = &dummy;
 
-	if (*pzName == '.') {
-	    noNesting = AG_TRUE;
-	    pzName++;
-	}
+        if (*pzName == '.') {
+            noNesting = AG_TRUE;
+            pzName++;
+        }
     }
 
     pcBrace  = pzName + strcspn( pzName, "[." );
@@ -413,18 +413,17 @@ defEntrySearch( char* pzName, tDefEntry* pDefs, ag_bool* pIsIndexed )
          *  IF we are at the end of the definitions (reached ROOT),
          *  THEN it is time to bail out.
          */
-        if (pDefs == (tDefEntry*)NULL)
+        pE = pDefStack->pDefs;
+        if (pE == (tDefEntry*)NULL)
             return (tDefEntry*)NULL;
 
-        pE = pDefs;
-
         do  {
             /*
              *  IF the name matches
              *  THEN break out of the double loop
              */
             if (strcmp( pE->pzDefName, pzName ) == 0)
-                goto label_defEntryFound;
+                goto found_def_entry;
 
             pE = pE->pNext;
         } while (pE != (tDefEntry*)NULL);
@@ -439,8 +438,10 @@ defEntrySearch( char* pzName, tDefEntry* pDefs, ag_bool* pIsIndexed )
         /*
          *  Let's go try the definitions at the next higher level.
          */
-        pDefs = pDefs->pDad ;
-    } label_defEntryFound:;
+        pDefStack = pDefStack->pPrev;
+        if (pDefStack == NULL)
+            return (tDefEntry*)NULL;
+    } found_def_entry:;
 
     /*
      *  At this point, we have found the entry that matches the supplied
@@ -515,39 +516,46 @@ defEntrySearch( char* pzName, tDefEntry* pDefs, ag_bool* pIsIndexed )
      *  used a subscript.
      */
     nestingDepth++;
-    do  {
-        tDefEntry* res = defEntrySearch( pzName, (tDefEntry*)pE->pzValue,
-                                       pIsIndexed );
-        if ((res != (tDefEntry*)NULL) || (breakCh == '[')) {
-            nestingDepth--;
-            return res;
+    {
+        tDefStack stack = { (tDefEntry*)pE->pzValue, &currDefCtx };
+        for (;;) {
+            tDefEntry* res;
+
+            res = defEntrySearch( pzName, &stack, pIsIndexed );
+            if ((res != (tDefEntry*)NULL) || (breakCh == '[')) {
+                nestingDepth--;
+                return res;
+            }
+            pE = pE->pTwin;
+            if (pE == NULL)
+                break;
+            stack.pDefs = (tDefEntry*)pE->pzValue;
         }
-        pE = pE->pTwin;
-    } while (pE != (tDefEntry*)NULL);
+    }
 
     nestingDepth--;
     return (tDefEntry*)NULL;
 }
 
+
     EXPORT tDefEntry*
 findDefEntry( char* pzName, ag_bool* pIsIndexed )
 {
-    return defEntrySearch( pzName, pDefContext, pIsIndexed );
+    return defEntrySearch( pzName, &currDefCtx, pIsIndexed );
 }
 
 
 /*
  *  findEntryList
  *
- *  Find the definition entry for the name passed in.
- *  It is okay to find block entries IFF they are found on the
- *  current level.  Once you start traversing up the tree,
- *  the macro must be a text macro.  Return an indicator saying if
- *  the element has been indexed (so the caller will not try
- *  to traverse the list of twins).
+ *  Find the definition entry for the name passed in.  It is okay to find
+ *  block entries IFF they are found on the current level.  Once you start
+ *  traversing up the tree, the macro must be a text macro.  Return an
+ *  indicator saying if the element has been indexed (so the caller will
+ *  not try to traverse the list of twins).
  */
     STATIC tDefEntry**
-entryListSearch( char* pzName, tDefEntry* pDefs )
+entryListSearch( char* pzName, tDefStack* pDefStack )
 {
     static tDefEntryList defList = { 0, 0, NULL, 0 };
 
@@ -567,10 +575,10 @@ entryListSearch( char* pzName, tDefEntry* pDefs )
         pzName = zDefinitionName;
         defList.usedCt = 0;
 
-	if (*pzName == '.') {
-	    noNesting = AG_TRUE;
-	    pzName++;
-	}
+        if (*pzName == '.') {
+            noNesting = AG_TRUE;
+            pzName++;
+        }
     }
 
     pcBrace  = pzName + strcspn( pzName, "[." );
@@ -582,11 +590,13 @@ entryListSearch( char* pzName, tDefEntry* pDefs )
          *  IF we are at the end of the definitions (reached ROOT),
          *  THEN it is time to bail out.
          */
-        if (pDefs == (tDefEntry*)NULL) {
+        pE = pDefStack->pDefs;
+        if (pE == (tDefEntry*)NULL) {
             /*
              *  Make sure we are not nested.  Once we start to nest,
              *  then we cannot "change definition levels"
              */
+        not_found:
             if (defList.nestLevel != 0) {
                 tSCC z[] =
                     "reached ROOT def resolving last subcomponent:  `%s'\n";
@@ -600,15 +610,13 @@ entryListSearch( char* pzName, tDefEntry* pDefs )
             return (tDefEntry**)NULL;
         }
 
-        pE = pDefs;
-
         do  {
             /*
              *  IF the name matches
              *  THEN go add it, plus all its twins
              */
             if (strcmp( pE->pzDefName, pzName ) == 0)
-                goto label_defEntryFound;
+                goto found_def_entry;
 
             pE = pE->pNext;
         } while (pE != (tDefEntry*)NULL);
@@ -623,8 +631,10 @@ entryListSearch( char* pzName, tDefEntry* pDefs )
         /*
          *  Let's go try the definitions at the next higher level.
          */
-        pDefs = pDefs->pDad ;
-    } label_defEntryFound:;
+        pDefStack = pDefStack->pPrev;
+        if (pDefStack == NULL)
+            goto not_found;
+    } found_def_entry:;
 
     /*
      *  At this point, we have found the entry that matches the supplied
@@ -702,12 +712,18 @@ entryListSearch( char* pzName, tDefEntry* pDefs )
      *  used a subscript.
      */
     defList.nestLevel++;
-    do  {
-        (void)entryListSearch( pzName, (tDefEntry*)pE->pzValue );
-        if (breakCh == '[')
-            break;
-        pE = pE->pTwin;
-    } while (pE != (tDefEntry*)NULL);
+    {
+        tDefStack stack = { (tDefEntry*)pE->pzValue, &currDefCtx };
+        for (;;) {
+            (void)entryListSearch( pzName, &stack );
+            if (breakCh == '[')
+                break;
+            pE = pE->pTwin;
+            if (pE == NULL)
+                break;
+            stack.pDefs = (tDefEntry*)pE->pzValue;
+        }
+    }
     defList.nestLevel--;
 
  returnResult:
@@ -716,10 +732,12 @@ entryListSearch( char* pzName, tDefEntry* pDefs )
 
     return defList.papDefEntry;
 }
+
+
     EXPORT tDefEntry**
 findEntryList( char* pzName )
 {
-    return entryListSearch( pzName, pDefContext );
+    return entryListSearch( pzName, &currDefCtx );
 }
 /*
  * Local Variables:
