@@ -11,7 +11,7 @@ static char yyrcsid[] = "$Id: skeleton.c,v 1.4 1993/12/21 18:45:32 jtc Exp $";
 #define YYPREFIX "yy"
 #line 2 "defParse.y"
 /*
- *  $Id: defParse.y,v 1.7 2000/03/21 03:05:22 bruce Exp $
+ *  $Id: defParse.y,v 1.8 2001/04/30 03:38:32 bkorb Exp $
  *  Parse rules for the macro definitions
  */
 
@@ -336,90 +336,89 @@ yyreduce:
     {
 case 1:
 #line 57 "defParse.y"
-{ yyval = makeMacro( (YYSTYPE)&rootEntry,
-                                  yyvsp[-1], VALTYP_BLOCK ); }
+{ yyval = (YYSTYPE)(rootDefCtx.pDefs = (tDefEntry*)yyvsp[-1]); }
 break;
 case 2:
-#line 65 "defParse.y"
+#line 64 "defParse.y"
 { yyval = yyvsp[0]; }
 break;
 case 3:
-#line 66 "defParse.y"
+#line 65 "defParse.y"
 { yyval = addSibMacro( yyvsp[-1], yyvsp[0] ); }
 break;
 case 4:
-#line 67 "defParse.y"
+#line 66 "defParse.y"
 { yyval = yyvsp[0]; }
 break;
 case 5:
-#line 71 "defParse.y"
+#line 70 "defParse.y"
 { yyval = identify( yyvsp[-1] ); }
 break;
 case 6:
-#line 75 "defParse.y"
+#line 74 "defParse.y"
 { yyval = makeMacro( yyvsp[-1], (YYSTYPE)"", VALTYP_TEXT ); }
 break;
 case 7:
-#line 78 "defParse.y"
+#line 77 "defParse.y"
 { yyval = makeMacroList( yyvsp[-3], yyvsp[-1], VALTYP_TEXT ); }
 break;
 case 8:
-#line 81 "defParse.y"
+#line 80 "defParse.y"
 { yyval = makeMacroList( yyvsp[-3], yyvsp[-1], VALTYP_BLOCK ); }
 break;
 case 9:
-#line 84 "defParse.y"
+#line 83 "defParse.y"
 { yyval = startList( yyvsp[0] ); }
 break;
 case 10:
-#line 85 "defParse.y"
+#line 84 "defParse.y"
 { yyval = appendList( yyvsp[-2], yyvsp[0] ); }
 break;
 case 11:
-#line 88 "defParse.y"
+#line 87 "defParse.y"
 { yyval = startList( yyvsp[0] ); }
 break;
 case 12:
-#line 89 "defParse.y"
+#line 88 "defParse.y"
 { yyval = appendList( yyvsp[-2], yyvsp[0] ); }
 break;
 case 13:
-#line 92 "defParse.y"
+#line 91 "defParse.y"
 { yyval = yyvsp[-1]; }
 break;
 case 14:
-#line 94 "defParse.y"
+#line 93 "defParse.y"
 { yyval = yyvsp[0]; }
 break;
 case 15:
-#line 95 "defParse.y"
+#line 94 "defParse.y"
 { yyval = yyvsp[0]; }
 break;
 case 16:
-#line 96 "defParse.y"
+#line 95 "defParse.y"
 { yyval = yyvsp[0]; }
 break;
 case 17:
-#line 98 "defParse.y"
+#line 97 "defParse.y"
 { yyval = yyvsp[0]; }
 break;
 case 18:
-#line 99 "defParse.y"
+#line 98 "defParse.y"
 { yyval = yyvsp[0]; }
 break;
 case 19:
-#line 102 "defParse.y"
+#line 101 "defParse.y"
 { yyval = findPlace( yyvsp[0], (YYSTYPE)NULL ); }
 break;
 case 20:
-#line 105 "defParse.y"
+#line 104 "defParse.y"
 { yyval = findPlace( yyvsp[-3], yyvsp[-1] ); }
 break;
 case 21:
-#line 108 "defParse.y"
+#line 107 "defParse.y"
 { yyval = findPlace( yyvsp[-3], yyvsp[-1] ); }
 break;
-#line 423 "y.tab.c"
+#line 422 "y.tab.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
