@@ -1,7 +1,7 @@
 /*  -*- Mode: C -*-
  *
  *  expFormat.c
- *  $Id: expFormat.c,v 1.33 2001/04/22 18:27:41 bkorb Exp $
+ *  $Id: expFormat.c,v 1.36 2001/05/08 04:27:32 bkorb Exp $
  *  This module implements formatting expression functions.
  */
 
@@ -96,12 +96,17 @@ static const char zDne[] = "%6$s"
 "%1$sFrom the definitions    %4$s\n"
 "%1$sand the template file   %5$s";
 
+static const char zDne2[] = "%6$s"
+"%1$sEDIT THIS FILE WITH CAUTION  (%2$s)\n"
+"%1$s\n"
+"%1$sIt has been AutoGen-ed  %3$s\n"
+"%1$sFrom the definitions    %4$s\n"
+"%1$sand the template file   %5$s";
+
 #include <string.h>
 
-#include "autogen.h"
-#include <guile/gh.h>
-#include "expGuile.h"
 #include "expr.h"
+#include "autogen.h"
 
 #ifndef HAVE_STRFTIME
 #  include "compat/strftime.c"
@@ -122,10 +127,11 @@ tSCC zNil[]      = "";
  * exparg: prefix, string for starting each output line
  * exparg: first_prefix, for the first output line, opt
  *
- * doc:  Generate a "Do Not Edit" warning string.
- *       The argument is a per-line string prefix.
- *       The optional second argument is a first-line prefix and
- *       activates the read-only editor hints:
+ * doc:  Generate a "DO NOT EDIT" or "EDIT WITH CARE" warning string.
+ *       Which depends on whether or not the @code{--writable} command line
+ *       option was set.  The argument is a per-line string prefix.
+ *       The optional second argument is a first-line prefix and,
+ *       in read-only mode, activates the editor hints:
  *       @*
  *       @example
  *       -*- buffer-read-only: t -*- vi: set ro:
@@ -163,7 +169,8 @@ ag_scm_dne( SCM prefix, SCM first )
         }
         memcpy( (void*)(zScribble + 128), (void*)SCM_CHARS( first ), len );
         zScribble[ len + 128 ] = NUL;
-        pzFirst = asprintf( zDne1, zScribble+128, zScribble );
+        pzFirst = asprintf( ENABLED_OPT( WRITABLE ) ? "%s\n" : zDne1,
+                            zScribble+128, zScribble );
     }
 
     {
@@ -172,7 +179,8 @@ ag_scm_dne( SCM prefix, SCM first )
         strftime( zScribble+128, 128, "%A %B %e, %Y at %r %Z", pTime );
     }
 
-    pzRes = asprintf( zDne, zScribble, pCurFp->pzOutName, zScribble+128,
+    pzRes = asprintf( ENABLED_OPT( WRITABLE ) ? zDne2 : zDne,
+                      zScribble, pCurFp->pzOutName, zScribble+128,
                       OPT_ARG( DEFINITIONS ), pzTemplFileName, pzFirst );
 
     if (pzRes == (char*)NULL) {
