@@ -1,5 +1,5 @@
 /*
- *  $Id: expGperf.c,v 1.5 2000/10/28 18:17:32 bkorb Exp $
+ *  $Id: expGperf.c,v 1.10 2001/05/05 22:16:26 bkorb Exp $
  *  This module implements the expression functions that should
  *  be part of Guile.
  */
@@ -26,21 +26,32 @@
 
 #include <string.h>
 
-#include "autogen.h"
-#include <guile/gh.h>
-#include "expGuile.h"
 #include "expr.h"
+#include "autogen.h"
 
 tSCC zMakeGperf[] =
 "gperf_%2$s=.ZZPURGE.$$/%2$s\n"
 "[ -d .ZZPURGE.$$ ] || mkdir .ZZPURGE.$$\n"
+
+/*
+ *  The following little scriplet will ensure that the junk we leave
+ *  around will be removed not more than three seconds after we finish.
+ *  The third argument to this format string is the process id of AutoGen.
+ */
 "( ( while ps -p %3$d ; do sleep 3 ; done\n"
 "    rm -rf .ZZPURGE.$$ ) > /dev/null 2>&1 & )\n"
+
 "cd .ZZPURGE.$$ || {\n"
 "  echo 'cannot mkdir and enter .ZZPURGE.$$' >&2\n"
 "  exit 1\n}\n"
 
-"( cat <<'_EOF_'\n"
+"( "
+
+/*
+ *  From here to the matching closing paren, we are constructing the
+ *  pgerf input file with every character written to stdout
+ */
+"cat <<'_EOF_'\n"
 "%%{\n"
 "#include <stdio.h>\n"
 "typedef struct index t_index;\n"
@@ -69,24 +80,36 @@ tSCC zMakeGperf[] =
 "}\n"
 "_EOF_\n"
 
-") | tee %2$s.gperf | gperf -t -D -k'*' > %2$s.c || exit 1\n"
+/*
+ *  Now save the text into a xx.gperf file and also pass it
+ *  through a pipe to gperf for it to do its thing.
+ */
+") | tee %2$s.gperf | gperf -t -D -k'*' > %2$s.c\n"
 
+/*
+ *  actually build the program using "make"
+ */
 "make %2$s || exit 1";
 
 
-tSCC zRunGperf[] = "${gperf_%s} %s || exit 1";
+tSCC zRunGperf[] = "${gperf_%s} %s";
 
 
 /*=gfunc make_gperf
  *
- * what:   build a perfect hash function
+ * what:   build a perfect hash function program
  * general_use:
  *
  * exparg: name , name of hash list
- * exparg: list , list of strings to hash ,, list
+ * exparg: strings , list of strings to hash ,, list
  *
- * doc:  build a program to perform perfect hashes of a known
- *       list of input strings.
+ * doc:  Build a program to perform perfect hashes of a known list of input
+ *       strings.  This function produces no output, but prepares a program
+ *       named, @file{gperf_<name>} for use by the gperf function
+ *       @xref{SCM gperf}.
+ *
+ *       This program will be obliterated within a few seconds after
+ *       AutoGen exits.
 =*/
     SCM
 ag_scm_make_gperf( SCM name, SCM hlist )
@@ -164,7 +187,13 @@ ag_scm_make_gperf( SCM name, SCM hlist )
  * exparg: name , name of hash list
  * exparg: str  , string to hash
  *
- * doc:  Hash the input string
+ * doc:  Perform the perfect hash on the input string.  This is only useful if
+ *       you have previously created a gperf program with the @code{make-gperf}
+ *       function @xref{SCM make-gperf}.  The @code{name} you supply here must
+ *       match the name used to create the program and the string to hash must
+ *       be one of the strings supplied in the @code{make-gperf} string list.
+ *
+ *       See the documentation for @command{gperf(1GNU)} for more details.
 =*/
     SCM
 ag_scm_gperf( SCM name, SCM str )
