@@ -1,6 +1,6 @@
 
 /*
- *  $Id: expGuile.c,v 1.18 2001/04/30 03:38:32 bkorb Exp $
+ *  $Id: expGuile.c,v 1.19 2001/05/05 20:13:52 bkorb Exp $
  *  This module implements the expression functions that should
  *  be part of Guile.
  */
@@ -27,10 +27,8 @@
 
 #include <string.h>
 
-#include "autogen.h"
-#include <guile/gh.h>
-#include "expGuile.h"
 #include "expr.h"
+#include "autogen.h"
 
 #ifndef HAVE_STRFTIME
 #  include "compat/strftime.c"
