@@ -1,6 +1,6 @@
 
 /*
- *  $Id: funcCase.c,v 1.26 2001/03/27 05:00:08 bkorb Exp $
+ *  $Id: funcCase.c,v 1.27 2001/05/28 18:12:44 bkorb Exp $
  *
  *  This module implements the CASE text function.
  */
@@ -1136,7 +1136,7 @@ MAKE_LOAD_PROC( Case )
      */
     pEsacMac = parseTemplate( pT, pMac+1, ppzScan );
     if (*ppzScan == (char*)NULL)
-        LOAD_ABORT( pT, pMac, "parse err" );
+        LOAD_ABORT( pT, pMac, "ESAC not found" );
 
     /*
      *  Tell the last select macro where its end is.
