@@ -1,6 +1,6 @@
 
 /*
- *  $Id: funcFor.c,v 1.22 2001/04/30 03:38:32 bkorb Exp $
+ *  $Id: funcFor.c,v 1.26 2001/05/28 18:15:38 bkorb Exp $
  *
  *  This module implements the FOR text function.
  */
@@ -50,45 +50,117 @@ doForEach( tTemplate*   pT,
 
 /*=gfunc first_for_p
  *
- * what: detect first iteration
- * doc:  Returns SCM_BOOL_T if the current, innermost FOR loop is
- *       on the first pass through the data.  @xref{FOR}.
+ * what:    detect first iteration
+ * exparg:  for_var, which for loop, opt
+ * doc:     Returns SCM_BOOL_T if the named FOR loop (or, if not named, the
+ *          current innermost loop) is on the first pass through the data.
+ *          Outside of any FOR loop, it returns SCM_UNDEFINED.
+ *          @xref{FOR}.
 =*/
     SCM
-ag_scm_first_for_p( void )
+ag_scm_first_for_p( SCM which )
 {
-    return ((forInfo.fi_depth > 0) && pFS->for_firstFor)
-           ? SCM_BOOL_T : SCM_BOOL_F;
+    if (forInfo.fi_depth <= 0)
+        return SCM_UNDEFINED;
+
+    if (! gh_string_p( which ))
+        return (pFS->for_firstFor) ? SCM_BOOL_T : SCM_BOOL_F;
+
+    {
+        int        ct;
+        tForState* p   = forInfo.fi_data + (forInfo.fi_depth - 1);
+        char*      pz  = gh_scm2newstr( which, &ct );
+        SCM        res = SCM_UNDEFINED;
+        ct = forInfo.fi_depth;
+
+        do  {
+            if (strcmp( p->for_pzName, pz ) == 0) {
+                res = (p->for_firstFor ? SCM_BOOL_T : SCM_BOOL_F);
+                break;
+            }
+            p--;
+        } while (--ct > 0);
+
+        free( (void*)pz );
+        return res;
+    }
 }
 
 
 /*=gfunc last_for_p
  *
- * what: detect last iteration
- * doc:  Returns SCM_BOOL_T if the current, innermost FOR loop is
- *       on the last pass through the data.  @xref{FOR}.
+ * what:    detect last iteration
+ * exparg:  for_var, which for loop, opt
+ * doc:     Returns SCM_BOOL_T if the named FOR loop (or, if not named, the
+ *          current innermost loop) is on the last pass through the data.
+ *          Outside of any FOR loop, it returns SCM_UNDEFINED.
+ *          @xref{FOR}.
 =*/
     SCM
-ag_scm_last_for_p( void )
+ag_scm_last_for_p( SCM which )
 {
-    return ((forInfo.fi_depth > 0) && pFS->for_lastFor)
-           ? SCM_BOOL_T : SCM_BOOL_F;
+    if (forInfo.fi_depth <= 0)
+        return SCM_UNDEFINED;
+
+    if (! gh_string_p( which ))
+        return (pFS->for_lastFor ? SCM_BOOL_T : SCM_BOOL_F);
+
+    {
+        int        ct;
+        tForState* p   = forInfo.fi_data + (forInfo.fi_depth - 1);
+        char*      pz  = gh_scm2newstr( which, &ct );
+        SCM        res = SCM_UNDEFINED;
+        ct = forInfo.fi_depth;
+
+        do  {
+            if (strcmp( p->for_pzName, pz ) == 0) {
+                res = (p->for_lastFor ? SCM_BOOL_T : SCM_BOOL_F);
+                break;
+            }
+            p--;
+        } while (--ct > 0);
+
+        free( (void*)pz );
+        return res;
+    }
 }
 
 
 /*=gfunc for_index
  *
- * what:  get current loop index
- * doc:   Returns the current index for innermost FOR loop.
- *        Outside of any FOR loop, it returns SCM_UNDEFINED.
- *        @xref{FOR}.
+ * what:    get current loop index
+ * exparg:  for_var, which for loop, opt
+ * doc:     Returns the current index for the named FOR loop.
+ *          If not named, then the index for the innermost loop.
+ *          Outside of any FOR loop, it returns SCM_UNDEFINED.
+ *          @xref{FOR}.
 =*/
     SCM
-ag_scm_for_index( void )
+ag_scm_for_index( SCM which )
 {
     if (forInfo.fi_depth <= 0)
         return SCM_UNDEFINED;
-    return gh_int2scm( pFS->for_index );
+    if (! gh_string_p( which ))
+        return gh_int2scm( pFS->for_index );
+
+    {
+        int        ct;
+        tForState* p   = forInfo.fi_data + (forInfo.fi_depth - 1);
+        char*      pz  = gh_scm2newstr( which, &ct );
+        SCM        res = SCM_UNDEFINED;
+        ct = forInfo.fi_depth;
+
+        do  {
+            if (strcmp( p->for_pzName, pz ) == 0) {
+                res = gh_int2scm( p->for_index );
+                break;
+            }
+            p--;
+        } while (--ct > 0);
+
+        free( (void*)pz );
+        return res;
+    }
 }
 
 
@@ -525,7 +597,7 @@ MAKE_HANDLER_PROC( For )
     pFS = forInfo.fi_data + (forInfo.fi_depth - 1);
     memset( (void*)pFS, 0, sizeof( tForState ));
     pFS->for_firstFor = AG_TRUE;
-	pFS->for_pzName   = pT->pzTemplText + pMac->ozName;
+    pFS->for_pzName   = pT->pzTemplText + pMac->ozName;
 
     if (OPT_VALUE_TRACE >= TRACE_BLOCK_MACROS)
         fprintf( pfTrace, "FOR %s loop in %s on line %d begins:\n",
@@ -630,7 +702,7 @@ MAKE_LOAD_PROC( For )
 
     pEndMac = parseTemplate( pT, pMac + 1, ppzScan );
     if (*ppzScan == (char*)NULL)
-        LOAD_ABORT( pT, pMac, "parse error" );
+        LOAD_ABORT( pT, pMac, "ENDFOR not found" );
 
     pMac->endIndex = pMac->sibIndex = pEndMac - pT->aMacros;
 
