@@ -1,6 +1,6 @@
 
 /*
- *  $Id: funcIf.c,v 1.13 2001/03/27 05:00:07 bkorb Exp $
+ *  $Id: funcIf.c,v 1.16 2001/05/28 18:15:01 bkorb Exp $
  *
  *  This module implements the _IF text function.
  */
@@ -26,9 +26,8 @@
  */
 #ifndef DEFINE_LOAD_FUNCTIONS
 
+#include "expr.h"
 #include "autogen.h"
-#include "proto.h"
-#include "expGuile.h"
 
 tSCC zNoIfEnd[]   = "%s ERROR:  cannot find ENDIF\n\t'%s'\n";
 
@@ -373,10 +372,8 @@ MAKE_LOAD_PROC( If )
      *  to the remaining text.
      */
     pEndifMac = parseTemplate( pT, pMac+1, ppzScan );
-    if (*ppzScan == (char*)NULL) {
-        fputs( "Unterminated IF block\n", stderr );
-        LOAD_ABORT( pT, pMac, "parse err" );
-    }
+    if (*ppzScan == (char*)NULL)
+        LOAD_ABORT( pT, pMac, "ENDIF not found" );
 
     current_if.pIf->endIndex   = \
     current_if.pElse->sibIndex = pEndifMac - pT->aMacros;
@@ -426,15 +423,14 @@ MAKE_LOAD_PROC( While )
     (void)mLoad_Expr( pT, pMac, ppzScan );
 
     /*
-     *  Now, do a nested parse of the template.
-     *  When the matching 'ENDIF' macro is encountered,
-     *  the handler routine will cause 'parseTemplate()'
-     *  to return with the text scanning pointer pointing
-     *  to the remaining text.
+     *  Now, do a nested parse of the template.  When the matching 'ENDWHILE'
+     *  macro is encountered, the handler routine will cause 'parseTemplate()'
+     *  to return with the text scanning pointer pointing to the remaining
+     *  text.
      */
     pEndMac = parseTemplate( pT, pMac+1, ppzScan );
     if (*ppzScan == (char*)NULL)
-        LOAD_ABORT( pT, pMac, "parse err" );
+        LOAD_ABORT( pT, pMac, "ENDWHILE not found" );
 
     pMac->sibIndex = pMac->endIndex = pEndMac - pT->aMacros;
 
@@ -444,6 +440,23 @@ MAKE_LOAD_PROC( While )
     papLoadProc = papLP;
     return pEndMac;
 }
+
+
+/*=gfunc set_writable
+ *
+ * what:   Make the output file be writable
+ *
+ * doc:    This function will set the current output file to be writable.
+ *         This is only effective if the command line option
+ *         @code{--not-writable} has not been specified.  This state
+ *         is reset when the current suffix's output is complete.
+=*/
+    SCM
+ag_scm_set_writable( void )
+{
+    SET_OPT_WRITABLE;
+    return SCM_UNDEFINED;
+}
 /*
  * Local Variables:
  * c-file-style: "stroustrup"
