@@ -1,6 +1,6 @@
 
 /*
- *  $Id: autoopts.c,v 2.30 2000/11/04 18:19:19 bkorb Exp $
+ *  $Id: autoopts.c,v 2.32 2001/05/27 14:21:29 bkorb Exp $
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -73,6 +73,9 @@
 #include "compat/compat.h"
 
 
+#define ISNAMECHAR( c )    (isalnum(c) || ((c) == '_') || ((c) == '-'))
+
+
 tSCC zBadVer[] = "Automated Options Processing Error!\n\
 \t%s called optionProcess with structure version %d.%d.%d.\n\
 \tThis library was compiled with version %d.%d.%d\n\
@@ -647,17 +650,18 @@ DEF_PROC_2( STATIC tSuccess nextOption,
  *  filePreset      is used by doLoadOpt() and doPresets()
  *
  *
- *  make_path  --  translate and construct a path
+ *  optionMakePath  --  translate and construct a path
  *
  *  This routine does environment variable expansion if the first character
  *  is a ``$''.  If it starts with two dollar characters, then the path
  *  is relative to the location of the executable.
  */
-DEF_PROC_4( STATIC ag_bool make_path,
-            char*,   pzBuf,
-            size_t,  bufSize,
-            tCC*,    pzName,
-            tCC*,    pzProgPath )
+ag_bool
+optionMakePath( pzBuf, bufSize, pzName, pzProgPath )
+    char*    pzBuf;
+    size_t   bufSize;
+    tCC*     pzName;
+    tCC*     pzProgPath;
 {
     if (bufSize <= strlen( pzName ))
         return AG_FALSE;
@@ -681,11 +685,12 @@ DEF_PROC_4( STATIC ag_bool make_path,
 
         if (strchr( pzProgPath, '/' ) != (char*)NULL)
             pzPath = pzProgPath;
-        else
+        else {
             pzPath = pathfind( getenv( "PATH" ), (char*)pzProgPath, "rx" );
 
-        if (pzPath == (char*)NULL)
-            return AG_FALSE;
+            if (pzPath == (char*)NULL)
+                return AG_FALSE;
+        }
 
         pz = strrchr( pzPath, '/' );
 
@@ -725,41 +730,32 @@ DEF_PROC_4( STATIC ag_bool make_path,
      *  (We will not accept any more env variables.)
      */
     else {
-        char* pzDir = strchr( pzName+1, '/' );
+        char* pzDir = pzBuf;
 
-        if (pzDir != (char*)NULL)
-            *pzDir = NUL;
-
-        {
-            char* pzEnv = getenv( pzName+1 );
-
-            /*
-             *  Environment value not found -- skip the home list entry
-             */
-            if (pzEnv == (char*)NULL)
-                return AG_FALSE;
-
-            if (strlen( pzEnv ) >= bufSize)
-                return AG_FALSE;
-
-            strcpy( pzBuf, pzEnv );
+        for (;;) {
+            char ch = *++pzName;
+            if (! ISNAMECHAR( ch ))
+                break;
+            *(pzDir++) = ch;
         }
 
+        if (pzDir == pzBuf)
+            return AG_FALSE;
+
+        *pzDir = NUL;
+
+        pzDir = getenv( pzBuf );
+
         /*
-         *  IF we found a directory that followed the env variable,
-         *  THEN tack it onto the value we found
+         *  Environment value not found -- skip the home list entry
          */
-        if (pzDir != (char*)NULL) {
-            if (strlen( pzBuf ) + 1 + strlen( pzDir+1 ) >= bufSize)
-                return AG_FALSE;
+        if (pzDir == (char*)NULL)
+            return AG_FALSE;
 
-            pzBuf += strlen( pzBuf );
+        if (strlen( pzDir ) + 1 + strlen( pzName ) >= bufSize)
+            return AG_FALSE;
 
-            if (pzBuf[-1] != '/')
-                *(pzBuf++) = '/';
-            strcpy( pzBuf, pzDir+1 );
-            *pzDir = '/';
-        }
+        sprintf( pzBuf, "%s%s", pzDir, pzName );
     }
 
     return AG_TRUE;
@@ -1097,9 +1093,10 @@ DEF_PROC_3( STATIC void filePreset,
  *  doEnvPresets - check for preset values from the envrionment
  *  This routine should process in all, immediate or normal modes....
  */
-DEF_PROC_2( STATIC void doEnvPresets,
-            tOptions*,       pOpts,
-            teEnvPresetType, type )
+    STATIC void
+doEnvPresets( pOpts, type )
+    tOptions*       pOpts;
+    teEnvPresetType type;
 {
     int        ct;
     tOptState  st;
@@ -1119,7 +1116,7 @@ DEF_PROC_2( STATIC void doEnvPresets,
 
     pzFlagName = zEnvName
         + snprintf( zEnvName, sizeof( zEnvName ), "%s_", pOpts->pzPROGNAME );
-    spaceLeft = (zEnvName - pzFlagName) - 1;
+    spaceLeft = sizeof( zEnvName ) - (pzFlagName - zEnvName) - 1;
 
     for (;ct-- > 0; st.pOD++) {
         /*
@@ -1280,8 +1277,8 @@ DEF_PROC_1( STATIC tSuccess doPresets,
 
             idx += inc;
 
-            if (! make_path( zFileName, sizeof( zFileName ),
-                             pzPath, pOpts->pzProgPath ))
+            if (! optionMakePath( zFileName, sizeof( zFileName ),
+                                  pzPath, pOpts->pzProgPath ))
                 continue;
 
             /*
