@@ -1,6 +1,6 @@
 
 /*
- *  $Id: pgusage.c,v 2.4 2000/04/10 14:03:32 bkorb Exp $
+ *  $Id: pgusage.c,v 2.7 2000/10/28 18:17:32 bkorb Exp $
  *
  *   Automated Options Paged Usage module.
  *
@@ -63,8 +63,9 @@ tePagerState pagerState = PAGER_STATE_INITIAL;
  *  Run the usage output through a pager.
  *  This is very handy if it is very long.
  */
-    void
-doPagedUsage( tOptions* pOptions, tOptDesc* pOD )
+DEF_PROC_2( void doPagedUsage,
+            tOptions*, pOptions,
+            tOptDesc*, pOD )
 {
     static pid_t     my_pid;
     char zPageUsage[ 1024 ];
@@ -78,7 +79,7 @@ doPagedUsage( tOptions* pOptions, tOptDesc* pOD )
     case PAGER_STATE_INITIAL:
     {
         my_pid  = getpid();
-        snprintf( zPageUsage, sizeof(zPageUsage), "/tmp/use.%lu", my_pid );
+        snprintf( zPageUsage, sizeof(zPageUsage), "/tmp/use.%lu", (tUL)my_pid );
         unlink( zPageUsage );
 
         /*
@@ -119,7 +120,7 @@ doPagedUsage( tOptions* pOptions, tOptDesc* pOD )
          */
         snprintf( zPageUsage, sizeof(zPageUsage),
                   "%s /tmp/use.%lu ; rm -f /tmp/use.%2$lu",
-                  pzPager, my_pid );
+                  pzPager, (tUL)my_pid );
         fclose( stderr );
         dup2( STDOUT_FILENO, STDERR_FILENO );
 
@@ -134,4 +135,8 @@ doPagedUsage( tOptions* pOptions, tOptDesc* pOD )
         break;
     }
 }
-/* pgusage.c ends here */
+/*
+ * Local Variables:
+ * c-file-style: "stroustrup"
+ * End:
+ * pgusage.c ends here */
