@@ -1,6 +1,6 @@
 
 /*
- *  save.c  $Id: save.c,v 2.7 2000/04/10 14:03:32 bkorb Exp $
+ *  save.c  $Id: save.c,v 2.10 2000/11/03 03:11:30 bkorb Exp $
  *
  *  This module's routines will take the currently set options and
  *  store them into an ".rc" file for re-interpretation the next
@@ -58,8 +58,8 @@
 
 tSCC  zWarn[] = "%s WARNING:  cannot save options - ";
 
-    STATIC char*
-findDirName( tOptions*  pOpts )
+DEF_PROC_1( STATIC char* findDirName,
+            tOptions*,  pOpts )
 {
     char*  pzDir;
 
@@ -90,7 +90,7 @@ findDirName( tOptions*  pOpts )
         return pzDir;
 
     {
-        char* pzEndDir = strchr( ++pzDir, DIR_SEP_CHAR );
+        char* pzEndDir = strchr( ++pzDir, '/' );
         char* pzFileName;
         char* pzEnv;
 
@@ -123,16 +123,16 @@ findDirName( tOptions*  pOpts )
         strcpy( pzFileName, pzEnv );
         pzDir = pzFileName + strlen( pzFileName );
 
-        while ((pzDir > pzFileName) && (pzDir[-1] == DIR_SEP_CHAR)) pzDir--;
-        *(pzDir++) = DIR_SEP_CHAR;
+        while ((pzDir > pzFileName) && (pzDir[-1] == '/')) pzDir--;
+        *(pzDir++) = '/';
         strcpy( pzDir, pzEndDir );
         return pzFileName;
     }
 }
 
 
-    STATIC char*
-findFileName( tOptions*  pOpts )
+DEF_PROC_1( STATIC char* findFileName,
+            tOptions*,  pOpts )
 {
     char*  pzDir;
     tSCC   zNoStat[] = "error %d (%s) stat-ing %s\n";
@@ -159,10 +159,10 @@ findFileName( tOptions*  pOpts )
              *  stat the remaining string
              *  and that string must name a directory
              */
-            char*  pzDirCh = strrchr( pzDir, DIR_SEP_CHAR );
-                        if (pzDirCh == (char*)NULL) {
+            char*  pzDirCh = strrchr( pzDir, '/' );
+            if (pzDirCh == (char*)NULL) {
                 stBuf.st_mode = S_IFREG;
-                break;
+                break;  /* bail out of error condition */
             }
 
             if (pzDirCh != (char*)NULL) {
@@ -175,7 +175,7 @@ findFileName( tOptions*  pOpts )
                      *  Restore the file name and mark the
                      *  full name as a regular file
                      */
-                    *pzDirCh = DIR_SEP_CHAR;
+                    *pzDirCh = '/';
                     stBuf.st_mode = S_IFREG;
 
                     break;  /* bail out of error condition */
@@ -200,7 +200,7 @@ findFileName( tOptions*  pOpts )
         char*  pzPath = (char*)AGALOC( sz );
 
         pzDir = pzPath;
-        snprintf( pzPath, sz, "%s%c%s", pzDir, DIR_SEP_CHAR, pOpts->pzRcName );
+        snprintf( pzPath, sz, "%s%c%s", pzDir, '/', pOpts->pzRcName );
 
         /*
          *  IF we cannot stat the object for any reason other than
@@ -239,8 +239,10 @@ findFileName( tOptions*  pOpts )
 }
 
 
-    STATIC void
-printEntry( FILE* fp, tOptDesc* p, char*  pzLA )
+DEF_PROC_3( STATIC void printEntry,
+            FILE*,      fp,
+            tOptDesc*,  p,
+            char*,      pzLA )
 {
     /*
      *  There is an argument.  Pad the name so values line up
@@ -289,8 +291,8 @@ printEntry( FILE* fp, tOptDesc* p, char*  pzLA )
 }
 
 
-    void
-optionSave( tOptions* pOpts )
+DEF_PROC_1( void optionSave,
+            tOptions*, pOpts )
 {
     char*  pzFName;
 
@@ -324,9 +326,8 @@ optionSave( tOptions* pOpts )
                      pzTime );
 #ifdef HAVE_ALLOCATED_CTIME
             /*
-             *  The return values for ctime(), localtime(), and
-             *  gmtime() point to static data whose content is
-             *  overwritten by each call.
+             *  The return values for ctime(), localtime(), and gmtime()
+             *  normally point to static data that is overwritten by each call.
              */
             free( (void*)pzTime );
 #endif
@@ -396,4 +397,8 @@ optionSave( tOptions* pOpts )
         fclose( fp );
     }
 }
-/* save.c ends here */
+/*
+ * Local Variables:
+ * c-file-style: "stroustrup"
+ * End:
+ * save.c ends here */
