@@ -8,7 +8,7 @@
  * Last Modified:      Thu Sep 23 23:03:15 1999
  *            by:      Gary V. Vaughan <gvv@techie.com>
  * ---------------------------------------------------------------------
- * @(#) $Id: format.c,v 1.6 2000/07/27 15:46:01 bkorb Exp $
+ * @(#) $Id: format.c,v 1.7 2001/05/05 02:59:53 bkorb Exp $
  * ---------------------------------------------------------------------
  */
 
@@ -900,7 +900,9 @@ DEFINE_PRINTFV_HANDLER(string_specifier_handler)
 	while ((count_or_errorcode >= 0) && *p != '\0'
 	       && ((prec == 0) || (count_or_errorcode - mark < len)))
 	{
-	    EMIT(*p++, stream, count_or_errorcode);
+        /*  The mask here ought to be unnecessary.  A good optimizer will
+            determine that it is unnecessary and skip it.  We hope.  */
+	    EMIT(0xFF & *(p++), stream, count_or_errorcode);
 	}
     }
 
